==================
icemac.addressbook
==================

Purpose:
    Store, search and export addresses and phone numbers using a web application.
Status:
    stable version, used in production; some features will be added in future

Copyright (c) 2008-2017 Michael Howitz

All Rights Reserved.

This software is subject to the provisions of the Zope Public License,
Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
FOR A PARTICULAR PURPOSE.

* Features_
* Screenshots_
* Download_
* Installation_
* Update_
* `Run the tests`_
* `Run the application`_
* `User management`_
* `To do`_

.. _Features : https://bitbucket.org/icemac/icemac.addressbook/wiki/Features
.. _Screenshots : https://bitbucket.org/icemac/icemac.addressbook/wiki/Screenshots
.. _Download : https://pypi.org/project/icemac.addressbook#download
.. _Installation : https://bitbucket.org/icemac/icemac.addressbook/wiki/Installation
.. _`User management` : https://bitbucket.org/icemac/icemac.addressbook/wiki/User%20management
.. _`Update` : https://bitbucket.org/icemac/icemac.addressbook/wiki/Update
.. _`Run the tests`: https://bitbucket.org/icemac/icemac.addressbook/wiki/Run_the_tests
.. _`Run the application` : https://bitbucket.org/icemac/icemac.addressbook/wiki/Run_the_application
.. _`To do` : https://bitbucket.org/icemac/icemac.addressbook/wiki/To%20do
